@@ -14,8 +14,8 @@ echo system.
 from .archiver import *
 from .msg import *
 from .script import *
-from .strext import *
+# from .strext import *
 from .tools import *
 from .venv import *
 
-_VERSION = '0.0.4'
+_VERSION = '0.0.5'
