@@ -140,7 +140,7 @@ def exec_batch(p_batch, p_verbose = False):
     for cmd in p_batch:
         rc = exec_cmd(cmd, p_verbose = p_verbose)
         if rc is not True:
-            success = success and False
+            success = False
     return success
 
 
